/* -----------------------------------------------
 * MainForm.cs
 * Author: Alex Nesterov
 * --------------------------------------------- */

using Genetibase.Shared;

using System;
using System.Diagnostics;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

namespace GenericMeters
{
	/// <summary>
	/// Application's main form.
	/// </summary>
	class MainForm : Form
	{
		#region Declarations
	
		private Container components = null;
		private Genetibase.UI.NuGenMeters.NuGenGraphGeneric nuGenGraphGeneric;
		private Genetibase.UI.NuGenMeters.NuGenMeterGeneric nuGenMeterGeneric;
		private System.Windows.Forms.GroupBox graphGroupBox;
		private System.Windows.Forms.ListBox graphCounterNameListBox;
		private System.Windows.Forms.ListBox meterCounterNameListBox;
		private System.Windows.Forms.GroupBox meterGroupBox;

		#endregion

		#region Methods.Private

		/// <summary>
		/// Populates the specified <see cref="T:ListBox"/> with counter name values available
		/// for the specified <see cref="T:ICounter"/> implementor.
		/// </summary>
		/// <param name="counter">The <see cref="T:INuGenCounter"/> implementor to read the parameters from.</param>
		/// <param name="listBox">The <see cref="T:ListBox"/> to populate.</param>
		private void PopulateCounterNameListBox(INuGenCounter counter, ListBox listBox)
		{
			Debug.Assert(counter != null, "counter != null");
			Debug.Assert(listBox != null, "listBox != null");

			if (counter == null)
			{
				throw new ArgumentNullException("counter");
			}

			if (listBox == null)
			{
				throw new ArgumentNullException("listBox");
			}

			string machineName = counter.MachineName;
			string categoryName = counter.CategoryName;

			try 
			{
				PerformanceCounterCategory category = new PerformanceCounterCategory(categoryName, machineName);
				
				string[] instances = category.GetInstanceNames();
				PerformanceCounter[] counters = null;

				if (instances.Length == 0) 
				{
					counters = category.GetCounters();
				}
				else 
				{
					counters = category.GetCounters(instances[0]);
				}

				string[] names = new string[counters.Length];

				for (int nameIndex = 0; nameIndex < counters.Length; nameIndex++) 
				{
					names[nameIndex] = counters[nameIndex].CounterName;
				}

				Array.Sort(names, Comparer.Default);

				listBox.Items.AddRange(names);
			}
			catch (Exception e)
			{
				Debug.WriteLine(string.Format("ERROR: {0}", e.Message));
			}
		}

		#endregion

		#region EventHandlers

		private void graphCounterNameListBox_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			this.nuGenGraphGeneric.Reset();
			this.nuGenGraphGeneric.CounterName = this.graphCounterNameListBox.SelectedItem.ToString();
		}

		private void meterCounterNameListBox_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			this.nuGenMeterGeneric.Reset();
			this.nuGenMeterGeneric.CounterName = this.meterCounterNameListBox.SelectedItem.ToString();
		}

		private void MainForm_Load(object sender, System.EventArgs e)
		{
			this.PopulateCounterNameListBox(this.nuGenGraphGeneric, this.graphCounterNameListBox);
			this.PopulateCounterNameListBox(this.nuGenMeterGeneric, this.meterCounterNameListBox);

			this.graphCounterNameListBox.SelectedIndex = 0;
			this.meterCounterNameListBox.SelectedIndex = 0;
		}

		#endregion

		#region Constructors

		/// <summary>
		/// Initializes a new instance of the <see cref="MainForm"/> class.
		/// </summary>
		public MainForm()
		{
			InitializeComponent();
		}
		
		#endregion

		#region Dispose

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose(bool disposing)
		{
			if (disposing)
			{
				if (components != null) components.Dispose();
			}
			
			base.Dispose(disposing);
		}
		
		#endregion

		#region Windows Form Designer generated code
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.nuGenGraphGeneric = new Genetibase.UI.NuGenMeters.NuGenGraphGeneric();
			this.nuGenMeterGeneric = new Genetibase.UI.NuGenMeters.NuGenMeterGeneric();
			this.graphGroupBox = new System.Windows.Forms.GroupBox();
			this.graphCounterNameListBox = new System.Windows.Forms.ListBox();
			this.meterGroupBox = new System.Windows.Forms.GroupBox();
			this.meterCounterNameListBox = new System.Windows.Forms.ListBox();
			this.graphGroupBox.SuspendLayout();
			this.meterGroupBox.SuspendLayout();
			this.SuspendLayout();
			// 
			// nuGenGraphGeneric
			// 
			this.nuGenGraphGeneric.CategoryName = "Processor";
			this.nuGenGraphGeneric.CounterName = "% C1 Time";
			this.nuGenGraphGeneric.InstanceName = "_Total";
			this.nuGenGraphGeneric.Location = new System.Drawing.Point(8, 24);
			this.nuGenGraphGeneric.MachineName = ".";
			this.nuGenGraphGeneric.Name = "nuGenGraphGeneric";
			this.nuGenGraphGeneric.Size = new System.Drawing.Size(250, 105);
			this.nuGenGraphGeneric.TabIndex = 0;
			// 
			// nuGenMeterGeneric
			// 
			this.nuGenMeterGeneric.CaptionText = "% Processor Time";
			this.nuGenMeterGeneric.CaptionTextBackColor = System.Drawing.SystemColors.Control;
			this.nuGenMeterGeneric.CaptionTextFont = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(204)));
			this.nuGenMeterGeneric.CaptionTextForeColor = System.Drawing.SystemColors.ControlText;
			this.nuGenMeterGeneric.CategoryName = "Processor";
			this.nuGenMeterGeneric.CounterFormat = "%";
			this.nuGenMeterGeneric.CounterName = "% Processor Time";
			this.nuGenMeterGeneric.InstanceName = "_Total";
			this.nuGenMeterGeneric.Location = new System.Drawing.Point(8, 16);
			this.nuGenMeterGeneric.MachineName = ".";
			this.nuGenMeterGeneric.Name = "nuGenMeterGeneric";
			this.nuGenMeterGeneric.Orientation = Genetibase.Shared.NuGenOrientationStyle.Horizontal;
			this.nuGenMeterGeneric.ProgressTextBackColor = System.Drawing.SystemColors.Control;
			this.nuGenMeterGeneric.ProgressTextBorderColor = System.Drawing.Color.Black;
			this.nuGenMeterGeneric.ProgressTextEdgeIndent = 50;
			this.nuGenMeterGeneric.ProgressTextFont = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(204)));
			this.nuGenMeterGeneric.ProgressTextForeColor = System.Drawing.SystemColors.ControlText;
			this.nuGenMeterGeneric.Size = new System.Drawing.Size(248, 104);
			this.nuGenMeterGeneric.TabIndex = 1;
			// 
			// graphGroupBox
			// 
			this.graphGroupBox.Controls.Add(this.graphCounterNameListBox);
			this.graphGroupBox.Controls.Add(this.nuGenGraphGeneric);
			this.graphGroupBox.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.graphGroupBox.Location = new System.Drawing.Point(8, 8);
			this.graphGroupBox.Name = "graphGroupBox";
			this.graphGroupBox.Size = new System.Drawing.Size(456, 136);
			this.graphGroupBox.TabIndex = 2;
			this.graphGroupBox.TabStop = false;
			this.graphGroupBox.Text = "Graph";
			// 
			// graphCounterNameListBox
			// 
			this.graphCounterNameListBox.IntegralHeight = false;
			this.graphCounterNameListBox.Location = new System.Drawing.Point(264, 24);
			this.graphCounterNameListBox.Name = "graphCounterNameListBox";
			this.graphCounterNameListBox.Size = new System.Drawing.Size(184, 104);
			this.graphCounterNameListBox.TabIndex = 1;
			this.graphCounterNameListBox.SelectedIndexChanged += new System.EventHandler(this.graphCounterNameListBox_SelectedIndexChanged);
			// 
			// meterGroupBox
			// 
			this.meterGroupBox.Controls.Add(this.meterCounterNameListBox);
			this.meterGroupBox.Controls.Add(this.nuGenMeterGeneric);
			this.meterGroupBox.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.meterGroupBox.Location = new System.Drawing.Point(8, 152);
			this.meterGroupBox.Name = "meterGroupBox";
			this.meterGroupBox.Size = new System.Drawing.Size(456, 128);
			this.meterGroupBox.TabIndex = 3;
			this.meterGroupBox.TabStop = false;
			this.meterGroupBox.Text = "Meter";
			// 
			// meterCounterNameListBox
			// 
			this.meterCounterNameListBox.IntegralHeight = false;
			this.meterCounterNameListBox.Location = new System.Drawing.Point(264, 16);
			this.meterCounterNameListBox.Name = "meterCounterNameListBox";
			this.meterCounterNameListBox.Size = new System.Drawing.Size(184, 104);
			this.meterCounterNameListBox.TabIndex = 2;
			this.meterCounterNameListBox.SelectedIndexChanged += new System.EventHandler(this.meterCounterNameListBox_SelectedIndexChanged);
			// 
			// MainForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(472, 286);
			this.Controls.Add(this.meterGroupBox);
			this.Controls.Add(this.graphGroupBox);
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedSingle;
			this.MaximizeBox = false;
			this.Name = "MainForm";
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
			this.Text = "GenericMeters";
			this.Load += new System.EventHandler(this.MainForm_Load);
			this.graphGroupBox.ResumeLayout(false);
			this.meterGroupBox.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		
		#endregion
	}
}
